==> igniteui-react-charts-16.6.4.tgz: package/ES2015/ScatterLineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
import { markType } from "igniteui-react-core/ES2015/type";
import { Color } from "igniteui-react-core/ES2015/Color";
export class ScatterLineSeriesView extends ScatterBaseView {
    constructor(a) {
        super(a);
        this.da = new Path();
    }
    a8() {
        super.a8();
        this.da._stroke = this.e.ku;
        this.da.ac = this.e.eu;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.da._stroke = a;
        this.da.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            a.s(this.da);
        }
    }
    c0(a) {
        super.c0(a);
        this.da.aj = null;
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.da, "shape", ["Main"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    }
}
ScatterLineSeriesView.$t = markType(ScatterLineSeriesView, 'ScatterLineSeriesView', ScatterBaseView.$);

==> igniteui-react-charts-16.6.8.tgz: package/ES2015/ScatterLineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
import { markType } from "igniteui-react-core/ES2015/type";
import { Color } from "igniteui-react-core/ES2015/Color";
/**
 * @hidden
 */
export class ScatterLineSeriesView extends ScatterBaseView {
    constructor(a) {
        super(a);
        this.da = new Path();
    }
    a8() {
        super.a8();
        this.da._stroke = this.e.kw;
        this.da.ac = this.e.ev;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.da._stroke = a;
        this.da.ac = this.e.ev + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            a.s(this.da);
        }
    }
    c0(a) {
        super.c0(a);
        this.da.aj = null;
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.da, "shape", ["Main"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k3 = a;
        this.e.es = 3;
        this.e.et = 1;
        this.e.eu = 4;
        this.e.dt = false;
    }
}
ScatterLineSeriesView.$t = markType(ScatterLineSeriesView, 'ScatterLineSeriesView', ScatterBaseView.$);
